==> paraview-v3.4.0.zip: paraview-v3.4.0/Qt/Components/pqActiveView.cxx <==
/*=========================================================================

   Program: ParaView
   Module:    pqActiveView.cxx

   Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2. 

   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/
#include "pqActiveView.h"

pqActiveView& pqActiveView::instance()
{
  static pqActiveView the_instance;
  return the_instance;
}

pqActiveView::pqActiveView() :
  ActiveView(0)
{
}

pqActiveView::~pqActiveView()
{
}

pqView* pqActiveView::current()
{
  return this->ActiveView;
}

void pqActiveView::setCurrent(pqView* view)
{
  if(this->ActiveView != view)
    {
    this->ActiveView = view;
    emit this->changed(view);
    }
}

==> paraview-v4.0.1.zip: paraview-v4.0.1/Qt/Components/pqActiveView.cxx <==
/*=========================================================================

   Program: ParaView
   Module:    pqActiveView.cxx

   Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2. 

   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/
#include "pqActiveView.h"

#include "pqView.h"
#include "pqActiveObjects.h"

//-----------------------------------------------------------------------------
pqActiveView& pqActiveView::instance()
{
  static pqActiveView the_instance;
  return the_instance;
}

//-----------------------------------------------------------------------------
pqActiveView::pqActiveView()
{
  pqActiveObjects* ao = &pqActiveObjects::instance();

  QObject::connect(ao, SIGNAL(viewChanged(pqView*)),
    this, SIGNAL(changed(pqView*)));
}

//-----------------------------------------------------------------------------
pqActiveView::~pqActiveView()
{
}

//-----------------------------------------------------------------------------
pqView* pqActiveView::current() const
{
  return pqActiveObjects::instance().activeView();
}

//-----------------------------------------------------------------------------
void pqActiveView::setCurrent(pqView* view)
{
  pqActiveObjects::instance().setActiveView(view);
}
